@@ -1,14 +1,49 @@
 use strict;
 use warnings;
-package String::Truncate;
-{
-  $String::Truncate::VERSION = '1.100601';
-}
+package String::Truncate 1.100603;
 # ABSTRACT: a module for when strings are too long to be displayed in...
 
 use Carp qw(croak);
 use Sub::Install 0.03 qw(install_sub);
 
+#pod =head1 SYNOPSIS
+#pod
+#pod This module handles the simple but common problem of long strings and finite
+#pod terminal width.  It can convert:
+#pod
+#pod  "this is your brain" -> "this is your ..."
+#pod                       or "...is your brain"
+#pod                       or "this is... brain"
+#pod                       or "... is your b..."
+#pod
+#pod It's simple:
+#pod
+#pod  use String::Truncate qw(elide);
+#pod
+#pod  my $brain = "this is your brain";
+#pod
+#pod  elide($brain, 16); # first option
+#pod  elide($brain, 16, { truncate => 'left' });   # second option
+#pod  elide($brain, 16, { truncate => 'middle' }); # third option
+#pod  elide($brain, 16, { truncate => 'ends' });   # fourth option
+#pod
+#pod  String::Trunc::trunc($brain, 16); # => "this is your bra"
+#pod
+#pod =func elide
+#pod
+#pod   elide($string, $length, \%arg)
+#pod
+#pod This function returns the string, if it is less than or equal to C<$length>
+#pod characters long.  If it is longer, it truncates the string and marks the
+#pod elision.
+#pod
+#pod Valid arguments are:
+#pod
+#pod  truncate - elide at left, right, middle, or ends? (default: right)
+#pod  marker   - how to mark the elision (default: ...)
+#pod  at_space - if true, strings will be broken at whitespace if possible
+#pod
+#pod =cut
 
 my %elider_for = (
   right  => \&_elide_right,
@@ -94,6 +129,14 @@ sub elide {
   return $elider->($string, $length, $marker, $at_space);
 }
   
+#pod =func trunc
+#pod
+#pod   trunc($string, $length, \%arg)
+#pod
+#pod This acts just like C<elide>, but assumes an empty marker, so it actually
+#pod truncates the string normally.
+#pod
+#pod =cut
 
 sub trunc {
   my ($string, $length, $arg) = @_;
@@ -105,6 +148,29 @@ sub trunc {
   return elide($string, $length, $arg);
 }
 
+#pod =head1 IMPORTING
+#pod
+#pod String::Truncate exports both C<elide> and C<trunc>, and also supports the
+#pod Exporter-style ":all" tag.
+#pod
+#pod   use String::Truncate ();        # export nothing
+#pod   use String::Truncate qw(elide); # export just elide()
+#pod   use String::Truncate qw(:all);  # export both elide() and trunc()
+#pod   use String::Truncate qw(-all);  # export both elide() and trunc()
+#pod
+#pod When exporting, you may also supply default values:
+#pod
+#pod   use String::Truncate -all => defaults => { length => 10, marker => '--' };
+#pod
+#pod   # or
+#pod
+#pod   use String::Truncate -all => { length => 10, marker => '--' };
+#pod
+#pod These values affect only the imported version of the functions.  You may pass
+#pod arguments as usual to override them, and you may call the subroutine by its
+#pod fully-qualified name to get the standard behavior.
+#pod
+#pod =cut
 
 use Sub::Exporter::Util ();
 use Sub::Exporter 0.953 -setup => {
@@ -117,6 +183,22 @@ use Sub::Exporter 0.953 -setup => {
   collectors => [ qw(defaults) ]
 };
 
+#pod =head1 BUILDING CODEREFS
+#pod
+#pod The imported builds and installs lexical closures (code references) that merge
+#pod in given values to the defaults.  You can build your own closures without
+#pod importing them into your namespace.  To do this, use the C<elide_with_defaults>
+#pod and C<trunc_with_defaults> routines.
+#pod
+#pod =head2 elide_with_defaults
+#pod
+#pod   my $elider = String::Truncate::elide_with_defaults(\%arg);
+#pod
+#pod This routine, never exported, builds a coderef which behaves like C<elide>, but
+#pod uses default values when needed.  All the valid arguments to C<elide> are valid
+#pod here, as well as C<length>.
+#pod
+#pod =cut
 
 sub _code_with_defaults {
   my ($code, $skip_defaults) = @_;
@@ -145,6 +227,13 @@ BEGIN {
   });
 }
 
+#pod =head2 trunc_with_defaults
+#pod
+#pod This routine behaves exactly like elide_with_defaults, with one obvious
+#pod exception: it returns code that works like C<trunc> rather than C<elide>.  If a
+#pod C<marker> argument is passed, it is ignored.
+#pod
+#pod =cut
 
 BEGIN {
   install_sub({
@@ -153,6 +242,25 @@ BEGIN {
   });
 }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<Text::Truncate> does a very similar thing.  So does L<Text::Elide>.
+#pod
+#pod =head1 BUGS
+#pod
+#pod Please report any bugs or feature requests through the web interface at
+#pod L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=String-Truncate>.  I will be
+#pod notified, and then you'll automatically be notified of progress on your bug as
+#pod I make changes.
+#pod
+#pod =head1 ACKNOWLEDGEMENTS
+#pod
+#pod Ian Langworth gave me some good advice about naming things.  (Also some bad
+#pod jokes.  Nobody wants String::ETOOLONG, Ian.)  Hans Dieter Pearcey suggested
+#pod allowing defaults just in time for a long bus ride, and I was rescued from
+#pod boredom by that suggestion
+#pod
+#pod =cut
 
 1; # End of String::Truncate
 
@@ -160,13 +268,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 String::Truncate - a module for when strings are too long to be displayed in...
 
 =head1 VERSION
 
-version 1.100601
+version 1.100603
 
 =head1 SYNOPSIS
 
@@ -191,6 +301,16 @@ It's simple:
 
  String::Trunc::trunc($brain, 16); # => "this is your bra"
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 FUNCTIONS
 
 =head2 elide
@@ -248,13 +368,13 @@ and C<trunc_with_defaults> routines.
   my $elider = String::Truncate::elide_with_defaults(\%arg);
 
 This routine, never exported, builds a coderef which behaves like C<elide>, but
-uses default values when needed.  All the valud arguments to C<elide> are valid
+uses default values when needed.  All the valid arguments to C<elide> are valid
 here, as well as C<length>.
 
 =head2 trunc_with_defaults
 
 This routine behaves exactly like elide_with_defaults, with one obvious
-exception: it retuns code that works like C<trunc> rather than C<elide>.  If a
+exception: it returns code that works like C<trunc> rather than C<elide>.  If a
 C<marker> argument is passed, it is ignored.
 
 =head1 SEE ALSO
@@ -277,11 +397,31 @@ boredom by that suggestion
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords David Steinbrunner Ricardo SIGNES Signes
+
+=over 4
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
